from ..MetaDataObject import MetaDataObject
from ..MetaDataObject.versions.CommonTemplate83 import CommonTemplate83


class CommonTemplate(MetaDataObject):

    versions = {
        '83': CommonTemplate83
    }
